@@ -11,7 +11,7 @@ class SklearnLoader(base_loader.BaseLoader):
 
         # write model to deployment instance environment
         model_path = f"{deployment_instance_path}/model"
-        with open(model_path, "w") as f_out:
+        with open(model_path, "wb") as f_out:
             f_out.write(model_artifact_model_binary)
 
         loaded_model = pickle.loads(model_artifact_model_binary)
